Features
========

.. autoclass:: pancad.geometry.AbstractFeature
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.Extrude
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.FeatureContainer
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.Sketch
    :show-inheritance:
    :members:

Enumerations
------------

.. autoclass:: pancad.geometry.constants.FeatureType
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.constants.SketchConstraint
    :show-inheritance:
    :members:
